import React, { useEffect, useState } from "react";
import "antd/dist/reset.css";
import "./App.css";
import PageContent from "./Components/PageContent";
import SideMenu from "./Components/SideMenu";
import Login from "./Pages/Login";
import { Layout } from "antd";
import {
  Constants,
  ClientUserDataContextPreview,
  ClientUserDataContext,
  UseUserSession,
  WebSocketProvider,
} from "./utils";

export default function App() {
  const { userSession, setUserSession } = UseUserSession();
  const [userData, setUserData] = useState(ClientUserDataContextPreview);

  useEffect(() => {
    if (!userSession) return;

    fetch(Constants.API_ADDRESS + "/user", {
      method: "GET",

      headers: {
        "Content-Type": "application/json",
        "X-Authorization": userSession,
      },
    })
      .then((res) => {
        if (res.status === 200) {
          return res.json();
        }

        setUserSession();
        return Promise.reject(res.status);
      })
      .then((data) => setUserData(data))
      .catch(console.error);
  }, []);

  if (!userSession) {
    return <Login setUserSession={setUserSession} />;
  }

  return (
    <Layout style={{ minHeight: "100vh" }}>
      <ClientUserDataContext.Provider value={userData}>
        <WebSocketProvider userSession={userSession}>
          <SideMenu setUserSession={setUserSession}></SideMenu>
          <PageContent></PageContent>
        </WebSocketProvider>
      </ClientUserDataContext.Provider>
    </Layout>
  );
}
