import {
  AppstoreOutlined,
  LogoutOutlined,
  SnippetsOutlined,
  UserOutlined,
} from "@ant-design/icons";
import { Badge, Divider, Menu } from "antd";
import Sider from "antd/es/layout/Sider";
import { useContext, useEffect, useState } from "react";
import { useLocation, useNavigate } from "react-router-dom";
import PropTypes from "prop-types";
import {
  ClientUserDataContext,
  Constants,
  UseUserSession,
  WebSocketTestContext,
} from "../../utils";

export default function SideMenu({ setUserSession }) {
  const { userSession } = UseUserSession();
  const location = useLocation();
  const [selectedKeys, setSelectedKeys] = useState("/");
  const clientUserDataContext = useContext(ClientUserDataContext);
  const webSocketTestContext = useContext(WebSocketTestContext);

  useEffect(() => {
    const pathName = location.pathname;
    setSelectedKeys(pathName);
  }, [location.pathname]);

  const navigate = useNavigate();
  return (
    <Sider
      theme="light"
      style={{ overflow: "auto", position: "fixed", height: "100vh" }}
    >
      <div
        style={{
          display: "flex",
          justifyContent: "space-between",
          flexDirection: "column",
          height: "100%",
        }}
      >
        <div>
          <div className="CompanyName">JANEX</div>
          <div className="Subtitle">Admin Dashboard</div>
          <Menu
            mode="vertical"
            onClick={(item) => {
              navigate(item.key);
            }}
            theme="light"
            selectedKeys={[selectedKeys]}
            items={[
              {
                label: "Dashboard",
                icon: <AppstoreOutlined />,
                key: "/",
              },
              {
                label: "Group Tasks",
                icon: <SnippetsOutlined />,
                key: "/group-tasks",
              },
            ]}
          />
        </div>
        <div>
          <Divider />
          <Menu
            selectable={false}
            mode="vertical"
            items={[
              {
                icon: (
                  <Badge
                    status={webSocketTestContext.connectionBadgeStatus}
                    text={`${
                      webSocketTestContext.connectedWebSocketUsersCount
                    } ${
                      webSocketTestContext.connectedWebSocketUsersCount == 1
                        ? "user"
                        : "users"
                    }  connected`}
                  />
                ),
              },
              {
                label: clientUserDataContext.Username,
                icon: <UserOutlined />,
              },
              {
                label: "Logout",
                icon: <LogoutOutlined />,
                onClick: () => {
                  setUserSession();
                  window.location.href = "/";

                  fetch(Constants.API_ADDRESS + "/user/auth/logout", {
                    method: "DELETE",
                    headers: {
                      "Content-Type": "application/json",
                      "X-Authorization": userSession,
                    },
                  }).catch(console.error);
                },
              },
            ]}
          />
        </div>
      </div>
    </Sider>
  );
}

SideMenu.propTypes = {
  setUserSession: PropTypes.func.isRequired,
};
