import { PlusOutlined } from "@ant-design/icons";
import { Badge, Button, Divider, Space, Table } from "antd";
import { useState } from "react";
import { Link } from "react-router-dom";
import GroupTaskModal from "./GroupTaskModal";
import TaskTypeSelectionModal from "./TaskTypeSelectionModal";

const columns = [
  {
    title: "ID",
    dataIndex: "id",
    key: "id",
  },
  {
    title: "Task Name",
    dataIndex: "taskname",
    key: "taskname",
  },
  {
    title: "Step",
    dataIndex: "step",
    key: "step",
  },
  {
    title: "Status",
    dataIndex: "status",
    key: "status",
  },
  {
    title: "Datetime",
    dataIndex: "datetime",
    key: "datetime",
  },
  {
    title: "Action",
    dataIndex: "action",
    key: "action",
    render: () => (
      <Space size="middle">
        <Link>View</Link>
      </Space>
    ),
  },
];

const data = [
  {
    key: "1",
    id: "12312",
    taskname: "Janex Device Acryl Led Lamp",
    step: "6 / 6",
    status: <Badge status="success" text="Finished" />,
    datetime: "2020-01-01 12:00:00",
  },
  {
    key: "2",
    id: "9999",
    taskname: "Acryl Glas schneiden",
    step: "3 / 6",
    status: <Badge status="error" text="Failed" />,
    datetime: "2020-01-01 12:00:00",
  },
];

export default function GroupTasks() {
  const [isTaskTypeModalOpen, setIsTaskTypeModalOpen] = useState(false);
  const [isGroupTaskModalOpen, setIsGroupTaskModalOpen] = useState(false);

  const showModal = (test) => {
    console.log(test);
    setIsTaskTypeModalOpen(true);
  };

  return (
    <>
      <h1 style={{ fontWeight: "bold" }}>GROUP TASKS</h1>

      <GroupTaskList
        category="Janex Device Acryl Led Lamp"
        showModal={showModal}
      />
      <GroupTaskList
        category="Janex Werkzeug"
        dataSource={false}
        showModal={showModal}
      />
      <GroupTaskList category="Roese" showModal={showModal} />
      <GroupTaskList category="Umbach" showModal={showModal} />

      <TaskTypeSelectionModal
        isOpen={isTaskTypeModalOpen}
        setIsOpen={setIsTaskTypeModalOpen}
        setIsGroupTaskModalOpen={setIsGroupTaskModalOpen}
      />

      <GroupTaskModal
        isOpen={isGroupTaskModalOpen}
        setIsOpen={setIsGroupTaskModalOpen}
      />
    </>
  );
}

function GroupTaskList({ category, dataSource, showModal }) {
  return (
    <>
      <Divider orientation="left">{category}</Divider>
      <Space style={{ marginBottom: 16 }}>
        <Button
          type="primary"
          icon={<PlusOutlined />}
          onClick={() => showModal(true)}
        >
          New task
        </Button>
      </Space>
      <Table
        columns={columns}
        dataSource={dataSource === false ? null : data}
      />
    </>
  );
}
